summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNathan Youngman <git@nathany.com>2012-10-27 23:41:52 -0600
committerNathan Youngman <git@nathany.com>2012-10-27 23:42:23 -0600
commit279348d3c2159df4ce6ac5949ada0177aa7c7159 (patch)
treee0ef2a73dc786397c698021fc8abba224e956409
parent308fd388b4646ff77263f05634547c6f3cc3e895 (diff)
downloadcoderay-279348d3c2159df4ce6ac5949ada0177aa7c7159.tar.gz
:map token kind
Use :map instead of :table. It's more generic, and won't be confused with the :table rendering style.
-rw-r--r--lib/coderay/scanners/lua.rb14
-rw-r--r--lib/coderay/styles/alpha.rb8
-rwxr-xr-xlib/coderay/token_kinds.rb20
3 files changed, 21 insertions, 21 deletions
diff --git a/lib/coderay/styles/alpha.rb b/lib/coderay/styles/alpha.rb
index 257083e..a60725b 100644
--- a/lib/coderay/styles/alpha.rb
+++ b/lib/coderay/styles/alpha.rb
@@ -1,6 +1,6 @@
module CodeRay
module Styles
-
+
# A colorful theme using CSS 3 colors (with alpha channel).
class Alpha < Style
@@ -116,9 +116,9 @@ table.CodeRay td { padding: 2px 4px; vertical-align: top; }
.symbol .content { color:#A60 }
.symbol .delimiter { color:#630 }
.symbol { color:#A60 }
-.table .content { color:#808 }
-.table .delimiter { color:#40A}
-.table { background-color:hsla(200,100%,50%,0.06); }
+.map .content { color:#808 }
+.map .delimiter { color:#40A}
+.map { background-color:hsla(200,100%,50%,0.06); }
.tag { color:#070 }
.type { color:#339; font-weight:bold }
.value { color: #088; }
diff --git a/lib/coderay/token_kinds.rb b/lib/coderay/token_kinds.rb
index e245623..a0ad5e4 100755
--- a/lib/coderay/token_kinds.rb
+++ b/lib/coderay/token_kinds.rb
@@ -1,14 +1,14 @@
module CodeRay
-
+
# A Hash of all known token kinds and their associated CSS classes.
TokenKinds = Hash.new do |h, k|
warn 'Undefined Token kind: %p' % [k] if $CODERAY_DEBUG
false
end
-
+
# speedup
TokenKinds.compare_by_identity if TokenKinds.respond_to? :compare_by_identity
-
+
TokenKinds.update( # :nodoc:
:annotation => 'annotation',
:attribute_name => 'attribute-name',
@@ -50,6 +50,7 @@ module CodeRay
:keyword => 'keyword',
:label => 'label',
:local_variable => 'local-variable',
+ :map => 'map',
:modifier => 'modifier',
:namespace => 'namespace',
:octal => 'octal',
@@ -63,29 +64,28 @@ module CodeRay
:shell => 'shell',
:string => 'string',
:symbol => 'symbol',
- :table => 'table',
:tag => 'tag',
:type => 'type',
:value => 'value',
:variable => 'variable',
-
+
:change => 'change',
:delete => 'delete',
:head => 'head',
:insert => 'insert',
-
+
:eyecatcher => 'eyecatcher',
-
+
:ident => false,
:operator => false,
-
+
:space => false,
:plain => false
)
-
+
TokenKinds[:method] = TokenKinds[:function]
TokenKinds[:escape] = TokenKinds[:delimiter]
TokenKinds[:docstring] = TokenKinds[:comment]
-
+
TokenKinds.freeze
end
diff --git a/lib/coderay/scanners/lua.rb b/lib/coderay/scanners/lua.rb
index e640397..64763dc 100644
--- a/lib/coderay/scanners/lua.rb
+++ b/lib/coderay/scanners/lua.rb
@@ -98,10 +98,10 @@ class CodeRay::Scanners::Lua < CodeRay::Scanners::Scanner
@encoder.text_token(match, kind)
elsif match = scan(/\{/) # Opening table brace {
- @encoder.begin_group(:table)
+ @encoder.begin_group(:map)
@encoder.text_token(match, @brace_depth >= 1 ? :inline_delimiter : :delimiter)
@brace_depth += 1
- @state = :table
+ @state = :map
elsif match = scan(/\}/) # Closing table brace }
if @brace_depth == 1
@@ -112,9 +112,9 @@ class CodeRay::Scanners::Lua < CodeRay::Scanners::Scanner
else
@brace_depth -= 1
@encoder.text_token(match, :inline_delimiter)
- @state = :table
+ @state = :map
end
- @encoder.end_group(:table)
+ @encoder.end_group(:map)
elsif match = scan(/["']/) # String delimiters " and '
@encoder.begin_group(:string)
@@ -142,8 +142,8 @@ class CodeRay::Scanners::Lua < CodeRay::Scanners::Scanner
# It may be that we’re scanning a full-blown subexpression of a table
# (tables can contain full expressions in parts).
- # If this is the case, return to :table scanning state.
- @state = :table if @state == :initial && @brace_depth >= 1
+ # If this is the case, return to :map scanning state.
+ @state = :map if @state == :initial && @brace_depth >= 1
when :function_expected
if match = scan(/\(.*?\)/m) # x = function() # "Anonymous" function without explicit name
@@ -237,7 +237,7 @@ class CodeRay::Scanners::Lua < CodeRay::Scanners::Scanner
@encoder.text_token(getch, :error)
end
- when :table
+ when :map
if match = scan(/[,;]/)
@encoder.text_token(match, :operator)
elsif match = scan(/[a-zA-Z_][a-zA-Z0-9_]* (?=\s*=)/x)